clear 
clear matrix
set mem 500m
set more off
ssc install estout
cap log close
log using estimation.log, replace
use data

**Fixup variables
rename boardrer rer
destring naics02_3, replace

**Generate metals dummy
gen metals = .
replace metals = 1 if naics02_3 == 331
replace metals = 0 if metals == .

**Convert to percentage points
foreach var in impshare_schott parts caplabor {
	replace `var' = `var' * 100
}

**Generate interaction terms
gen mer_X_rauch_avg_con_dum_flex = mer*rauch_avg_con_dum_flex
gen mer_X_impshare_schott = mer*impshare_schott
gen mer_X_parts = mer*parts

**Generate share
egen tot = total(AD_count), by (year)
gen AD_share = 100*AD_count / tot

**Generate fixed effects
tab year, gen(yr)
tab naics02_3, gen(ind)

**Generate lAD_SR (%)
xtset naics02_3 year
gen lAD_SR = 100*l.AD_SR
gen lAD_SR2 = lAD_SR^2
gen dlAD_SR = d.lAD_SR

**Generate labels
label variable AD_count "AD count"
label variable AD_share "AD share (%)"
label variable lAD_SR "AD Success Rate (%)"
label variable mer "Real Exchange Rate (MER)"
label variable rer REER
label variable metals "Primary Metals"
label variable rauch_avg_con_dum_flex "Pass-Through (PT)"
label variable parts "Imported Inputs (%)"
label variable impshare_schott "Import Share (%)"
label variable mer_X_rauch_avg_con_dum_flex "MER*PT"
label variable mer_X_parts "MER*Imported Inputs"
label variable mer_X_impshare_schott "MER*Import Share"
label variable dlnmcap "dln(Capacity Utilization)"
label variable caplabor "Capital-Labor Ratio (%)"
label variable dlncaplabor "dln(Capital-Labor Ratio)"
label variable conc4 "Concentration Ratio (%)"
label variable lnconc4 "ln(Concentration Ratio)"


**ESTIMATION

**Table 1: Metals vs. Non-Metals
eststo: xtnbreg AD_count mer, fe
eststo: xtnbreg AD_count mer metals, re
eststo: xtnbreg AD_count mer if metals==1, fe
eststo: xtnbreg AD_count mer if metals==0, fe
esttab using table1.rtf, replace onecell compress b(3) star(* 0.10 ** 0.05 *** 0.01) se sfmt(a3) label ///
scalars("N Observations" "N_g Groups" "cmd Model" "model Fixed effects" "p P-Value" "chi2 Chi-squared") ///
title("Table 1: Antidumping Petitions and Exchange Rates by Industry") mtitle("All Industries" "All Industries" "Metals" "Non-Metals")
eststo clear

**Table 2: All Industries
eststo: xtnbreg AD_count lAD_SR mer rauch_avg_con_dum_flex impshare_schott, re
eststo: xtnbreg AD_count lAD_SR mer rauch_avg_con_dum_flex impshare_schott mer_X_rauch_avg_con_dum_flex mer_X_impshare_schott, re
eststo: xtnbreg AD_count lAD_SR mer rauch_avg_con_dum_flex impshare_schott mer_X_rauch_avg_con_dum_flex mer_X_impshare_schott metals dlnmcap caplabor conc4, re
eststo: xtnbreg AD_count lAD_SR mer rauch_avg_con_dum_flex impshare_schott mer_X_rauch_avg_con_dum_flex mer_X_impshare_schott metals dlnmcap caplabor conc4 yr*, re
eststo: xtreg AD_share lAD_SR mer rauch_avg_con_dum_flex impshare_schott mer_X_rauch_avg_con_dum_flex mer_X_impshare_schott metals dlnmcap caplabor conc4, re
esttab using table2.rtf, replace drop(yr* o*) onecell compress b(3) star(* 0.10 ** 0.05 *** 0.01) se sfmt(a3) label nodep ///
scalars("N Observations" "N_g Groups" "cmd Model" "model Year Fixed Effects" "p P-Value" "chi2 Chi-squared") ///
title("Table 2: Determinants of Protectionist Response to Currency Appreciation") mtitle("AD Count" "AD Count" "AD Count" "AD Count" "AD Share")


**GRAPHS

**Figure 4: Marginal Effects Plot
xtnbreg AD_count lAD_SR c.mer##i.rauch_avg_con_dum_flex c.mer##c.impshare_schott metals dlnmcap caplabor conc4, re
margins, dydx(mer) over(rauch_avg_con_dum_flex)
cap marginsplot, yline(0) title("Average Marginal Effects of the Exchange Rate (MER) conditioned by Pass-Through")
graph save figure4.pdf, replace


cap log close
